| Title: | Distance Recordings from a Paper Plane Folding/Flying Experiment |
|---|---|
| Description: | This is a data only package, that provides distances from a paper plane experiment. |
| Authors: | Andreas Leha [aut, cre], Roland Gera [aut], Julia Bel [aut], Thomas Asendorf [aut], Marius Placzek [aut], Xenia Schulz [aut], Astrid Wachter [aut] |
| Maintainer: | Andreas Leha <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.1.9 |
| Built: | 2026-05-25 10:03:58 UTC |
| Source: | https://github.com/cran/paperplanes |
Distance Recordings from a Paper Plane Folding/Flying Experiment
paperplanespaperplanes
A data frame with eight variables:
id,
hour (the hour of the day),
person,
gender,
age,
plane,
paper (two types: 80g and 120g),
distance (recorded in meter).
Visitors of a science fair (the 3. 'Nacht des Wissens' in Goettingen/Germany http://www.ndw.uni-goettingen.de/) had the opportunity to throw a paper plane – either folding one themselves or re-using an existing one.